.*: Assembler messages:
.*: Error: symbol definition loop .*
.*: Error: can't resolve .*
.*: Error: symbol definition loop .*
.*: Error: can't resolve .*
.*: Error: symbol definition loop .*
.*: Error: can't resolve .*
.*: Error: symbol definition loop .*
.*: Error: can't resolve .*
.*: Error: symbol definition loop .*
.*: Error: can't resolve .*
#...
.*: Error: symbol definition loop .*
#...
.*: Error: can't resolve .*
.*: Error: symbol definition loop .*
#...
.*: Error: can't resolve .*
#pass
