.*: Assembler messages:
.*:3: Error: illegal operands \(vd must be even\) `smt.vmadot v1,v3,v4'
.*:4: Error: illegal operands \(vd must be even\) `smt.vmadotu v1,v3,v4'
.*:5: Error: illegal operands \(vd must be even\) `smt.vmadotsu v1,v3,v4'
.*:6: Error: illegal operands \(vd must be even\) `smt.vmadotus v1,v3,v4'
.*:7: Error: illegal operands \(vd must be even\) `smt.vmadot1u v1,v4,v5'
.*:8: Error: illegal operands \(vd must be even\) `smt.vmadot1 v1,v4,v5'
.*:9: Error: illegal operands \(vd must be even\) `smt.vmadot1su v1,v4,v5'
.*:10: Error: illegal operands \(vd must be even\) `smt.vmadot1us v1,v4,v5'
.*:11: Error: illegal operands \(vd must be even\) `smt.vmadot2u v1,v4,v5'
.*:12: Error: illegal operands \(vd must be even\) `smt.vmadot2 v1,v4,v5'
.*:13: Error: illegal operands \(vd must be even\) `smt.vmadot2su v1,v4,v5'
.*:14: Error: illegal operands \(vd must be even\) `smt.vmadot2us v1,v4,v5'
.*:15: Error: illegal operands \(vd must be even\) `smt.vmadot3u v1,v4,v5'
.*:16: Error: illegal operands \(vd must be even\) `smt.vmadot3 v1,v4,v5'
.*:17: Error: illegal operands \(vd must be even\) `smt.vmadot3su v1,v4,v5'
.*:18: Error: illegal operands \(vd must be even\) `smt.vmadot3us v1,v4,v5'
.*:20: Error: illegal operands \(vs1 must be even\) `smt.vmadot1u v2,v3,v5'
.*:21: Error: illegal operands \(vs1 must be even\) `smt.vmadot1 v2,v3,v5'
.*:22: Error: illegal operands \(vs1 must be even\) `smt.vmadot1su v2,v3,v5'
.*:23: Error: illegal operands \(vs1 must be even\) `smt.vmadot1us v2,v3,v5'
.*:24: Error: illegal operands \(vs1 must be even\) `smt.vmadot2u v2,v3,v5'
.*:25: Error: illegal operands \(vs1 must be even\) `smt.vmadot2 v2,v3,v5'
.*:26: Error: illegal operands \(vs1 must be even\) `smt.vmadot2su v2,v3,v5'
.*:27: Error: illegal operands \(vs1 must be even\) `smt.vmadot2us v2,v3,v5'
.*:28: Error: illegal operands \(vs1 must be even\) `smt.vmadot3u v2,v3,v5'
.*:29: Error: illegal operands \(vs1 must be even\) `smt.vmadot3 v2,v3,v5'
.*:30: Error: illegal operands \(vs1 must be even\) `smt.vmadot3su v2,v3,v5'
.*:31: Error: illegal operands \(vs1 must be even\) `smt.vmadot3us v2,v3,v5'
.*:33: Error: illegal operands \(invalid data type\) `smt.vmadot1u v2,v4,v5,i4'
.*:34: Error: illegal operands \(invalid data type\) `smt.vmadot1 v2,v4,v5,i4'
.*:35: Error: illegal operands \(invalid data type\) `smt.vmadot1su v2,v4,v5,i4'
.*:36: Error: illegal operands \(invalid data type\) `smt.vmadot1us v2,v4,v5,i4'
.*:37: Error: illegal operands \(invalid data type\) `smt.vmadot2u v2,v4,v5,i4'
.*:38: Error: illegal operands \(invalid data type\) `smt.vmadot2 v2,v4,v5,i4'
.*:39: Error: illegal operands \(invalid data type\) `smt.vmadot2su v2,v4,v5,i4'
.*:40: Error: illegal operands \(invalid data type\) `smt.vmadot2us v2,v4,v5,i4'
.*:41: Error: illegal operands \(invalid data type\) `smt.vmadot3u v2,v4,v5,i4'
.*:42: Error: illegal operands \(invalid data type\) `smt.vmadot3 v2,v4,v5,i4'
.*:43: Error: illegal operands \(invalid data type\) `smt.vmadot3su v2,v4,v5,i4'
.*:44: Error: illegal operands \(invalid data type\) `smt.vmadot3us v2,v4,v5,i4'
.*:46: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i1'
.*:47: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i2'
.*:48: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i3'
.*:49: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i5'
.*:50: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i7'
.*:51: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i16'
.*:52: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i32'
.*:53: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i64'
.*:54: Error: illegal operands \(invalid data type\) `smt.vmadot v2,v3,v4,i40'
.*:55: Error: illegal operands \(invalid data type\) `smt.vmadot1u v2,v4,v5,i2'
.*:56: Error: illegal operands \(invalid data type\) `smt.vmadot2u v2,v4,v5,i16'
.*:57: Error: illegal operands \(invalid data type\) `smt.vmadot3u v2,v4,v5,i32'
.*:60: Error: illegal operands \(vd must be even\) `smt.vmadotu.sp v1,v4,v5,v0,0,i8'
.*:61: Error: illegal operands \(vs1 must be even\) `smt.vmadotu.sp v2,v3,v5,v0,0,i8'
.*:63: Error: illegal operands \(mask must be v0/v1\) `smt.vmadotu.sp v2,v4,v5,v2,0,i8'
.*:65: Error: illegal operands \(invalid data type\) `smt.vmadotu.sp v2,v4,v5,v0,2,i4'
.*:66: Error: illegal operands \(invalid data type\) `smt.vmadotu.sp v2,v4,v5,v0,3,i4'
.*:68: Error: bad value for stride field, value must be 0\.\.3
.*:68: Error: illegal operands `smt.vmadotu.sp v2,v4,v5,v0,4,i8'
.*:70: Error: illegal operands \(mask must be v0/v1\) `smt.vmadotu.hp v2,v3,v4,v2,0,i4'
.*:72: Error: improper immediate value \(8\)
.*:74: Error: illegal operands \(vd must be even\) `smt.vfwmadot v1,v3,v4'
.*:75: Error: illegal operands \(vd must be even\) `smt.vfwmadot1 v1,v4,v5'
.*:76: Error: illegal operands \(vd must be even\) `smt.vfwmadot2 v1,v4,v5'
.*:77: Error: illegal operands \(vd must be even\) `smt.vfwmadot3 v1,v4,v5'
.*:79: Error: illegal operands \(vs1 must be even\) `smt.vfwmadot1 v2,v3,v5'
.*:80: Error: illegal operands \(vs1 must be even\) `smt.vfwmadot2 v2,v3,v5'
.*:81: Error: illegal operands \(vs1 must be even\) `smt.vfwmadot3 v2,v3,v5'
.*:83: Error: improper immediate value \(4\)
.*:84: Error: improper immediate value \(4\)
.*:85: Error: improper immediate value \(4\)
.*:86: Error: improper immediate value \(4\)
.*:88: Error: illegal operands \(vd must be even\) `smt.vpack.vv v1,v3,v4,0'
.*:89: Error: improper immediate value \(4\)
.*:90: Error: illegal operands \(vd must be even\) `smt.vupack.vv v1,v3,v4,0'
.*:91: Error: improper immediate value \(4\)
.*:96: Error: illegal operands \(invalid data type\) \`smt\.vmadot v2,v3,v4,i4'
.*:97: Error: illegal operands \(invalid data type\) \`smt\.vmadotu v2,v3,v4,i4'
.*:98: Error: illegal operands \(invalid data type\) \`smt\.vmadotsu v2,v3,v4,i4'
.*:99: Error: illegal operands \(invalid data type\) \`smt\.vmadotus v2,v3,v4,i4'
.*:100: Error: unrecognized opcode \`smt\.vmadotu\.sp v2,v4,v5,v0,0,i4', extension \`xsmtvdotii' required
.*:101: Error: unrecognized opcode \`smt\.vmadot\.sp v2,v4,v5,v0,0,i4', extension \`xsmtvdotii' required
.*:102: Error: unrecognized opcode \`smt\.vmadotsu\.sp v2,v4,v5,v0,0,i4', extension \`xsmtvdotii' required
.*:103: Error: unrecognized opcode \`smt\.vmadotus\.sp v2,v4,v5,v0,0,i4', extension \`xsmtvdotii' required
.*:104: Error: unrecognized opcode \`smt\.vmadotu\.hp v2,v3,v4,v0,0,i4', extension \`xsmtvdotii' required
.*:105: Error: unrecognized opcode \`smt\.vmadot\.hp v2,v3,v4,v0,0,i4', extension \`xsmtvdotii' required
.*:106: Error: unrecognized opcode \`smt\.vmadotsu\.hp v2,v3,v4,v0,0,i4', extension \`xsmtvdotii' required
.*:107: Error: unrecognized opcode \`smt\.vmadotus\.hp v2,v3,v4,v0,0,i4', extension \`xsmtvdotii' required
.*:108: Error: unrecognized opcode \`smt\.vfwmadot v2,v3,v4', extension \`xsmtvdotii' required
.*:109: Error: unrecognized opcode \`smt\.vfwmadot1 v2,v4,v5', extension \`xsmtvdotii' required
.*:110: Error: unrecognized opcode \`smt\.vfwmadot2 v2,v4,v5', extension \`xsmtvdotii' required
.*:111: Error: unrecognized opcode \`smt\.vfwmadot3 v2,v4,v5', extension \`xsmtvdotii' required
.*:112: Error: unrecognized opcode \`smt\.vnpack\.vv v2,v3,v4,0', extension \`xsmtvdotii' required
.*:113: Error: unrecognized opcode \`smt\.vnspack\.vv v2,v3,v4,0', extension \`xsmtvdotii' required
.*:114: Error: unrecognized opcode \`smt\.vnpack4\.vv v2,v3,v4,0', extension \`xsmtvdotii' required
.*:115: Error: unrecognized opcode \`smt\.vnspack4\.vv v2,v3,v4,0', extension \`xsmtvdotii' required
.*:116: Error: unrecognized opcode \`smt\.vpack\.vv v2,v3,v4,0', extension \`xsmtvdotii' required
.*:117: Error: unrecognized opcode \`smt\.vupack\.vv v2,v3,v4,0', extension \`xsmtvdotii' required
