target:
	vsetvli zero, zero, e8alt, mf2, tu, mu
	vsetvli zero, zero, e8alt, mf2, tu, mu
	vsetvli zero, zero, e8alt, mf2, tu, mu
	vsetvli zero, zero, e16alt, mf2, tu, mu
	vsetvli zero, zero, e16alt, mf2, tu, mu
	vsetvli zero, zero, e16alt, mf2, tu, mu
