target:
	smt.vmadot v2, v3, v4
	smt.vmadotu v2, v3, v4
	smt.vmadotsu v2, v3, v4
	smt.vmadotus v2, v3, v4
	smt.vmadot1u v2, v4, v5
	smt.vmadot1 v2, v4, v5
	smt.vmadot1su v2, v4, v5
	smt.vmadot1us v2, v4, v5
	smt.vmadot2u v2, v4, v5
	smt.vmadot2 v2, v4, v5
	smt.vmadot2su v2, v4, v5
	smt.vmadot2us v2, v4, v5
	smt.vmadot3u v2, v4, v5
	smt.vmadot3 v2, v4, v5
	smt.vmadot3su v2, v4, v5
	smt.vmadot3us v2, v4, v5
	smt.vmadot v2, v3, v4, i8
	smt.vmadotu v2, v3, v4, i8
	smt.vmadotsu v2, v3, v4, i8
	smt.vmadotus v2, v3, v4, i8
	smt.vmadot1u v2, v4, v5, i8
	smt.vmadot1 v2, v4, v5, i8
	smt.vmadot1su v2, v4, v5, i8
	smt.vmadot1us v2, v4, v5, i8
	smt.vmadot2u v2, v4, v5, i8
	smt.vmadot2 v2, v4, v5, i8
	smt.vmadot2su v2, v4, v5, i8
	smt.vmadot2us v2, v4, v5, i8
	smt.vmadot3u v2, v4, v5, i8
	smt.vmadot3 v2, v4, v5, i8
	smt.vmadot3su v2, v4, v5, i8
	smt.vmadot3us v2, v4, v5, i8
