.*: Assembler messages:
.*:2: Warning: `unaligned_access' attribute with non-boolean value
.*:5: Warning: `stack_align' attribute with non-power-of-2 value
.*:6: Warning: `stack_align' attribute with non-power-of-2 value
