.*: Assembler messages:
.*: Error: illegal operands `fadd\.q .*'
.*: Error: illegal operands `fadd\.q .*'
.*: Error: illegal operands `fsub\.q .*'
.*: Error: illegal operands `fsub\.q .*'
.*: Error: illegal operands `fmul\.q .*'
.*: Error: illegal operands `fmul\.q .*'
.*: Error: illegal operands `fdiv\.q .*'
.*: Error: illegal operands `fdiv\.q .*'
.*: Error: illegal operands `fsqrt\.q .*'
.*: Error: illegal operands `fsqrt\.q .*'
.*: Error: illegal operands `fmin\.q .*'
.*: Error: illegal operands `fmax\.q .*'
.*: Error: illegal operands `fmadd\.q .*'
.*: Error: illegal operands `fmadd\.q .*'
.*: Error: illegal operands `fnmadd\.q .*'
.*: Error: illegal operands `fnmadd\.q .*'
.*: Error: illegal operands `fmsub\.q .*'
.*: Error: illegal operands `fmsub\.q .*'
.*: Error: illegal operands `fnmsub\.q .*'
.*: Error: illegal operands `fnmsub\.q .*'
.*: Error: unrecognized opcode `fcvt\.l\.q .*'
.*: Error: unrecognized opcode `fcvt\.l\.q .*'
.*: Error: unrecognized opcode `fcvt\.lu\.q .*'
.*: Error: unrecognized opcode `fcvt\.lu\.q .*'
.*: Error: illegal operands `fcvt\.q\.w .*'
.*: Error: illegal operands `fcvt\.q\.wu .*'
.*: Error: unrecognized opcode `fcvt\.q\.l .*'
.*: Error: unrecognized opcode `fcvt\.q\.lu .*'
.*: Error: illegal operands `fcvt\.q\.s .*'
.*: Error: illegal operands `fcvt\.q\.d .*'
.*: Error: illegal operands `fsgnj\.q .*'
.*: Error: illegal operands `fsgnjn\.q .*'
.*: Error: illegal operands `fsgnjx\.q .*'
.*: Error: illegal operands `feq\.q .*'
.*: Error: illegal operands `flt\.q .*'
.*: Error: illegal operands `fle\.q .*'
.*: Error: illegal operands `fgt\.q .*'
.*: Error: illegal operands `fge\.q .*'
.*: Error: illegal operands `fmv\.q .*'
.*: Error: illegal operands `fneg\.q .*'
.*: Error: illegal operands `fabs\.q .*'
