.*: Assembler messages:
.*:4: Error: unrecognized extended version of MIPS16 opcode `div\.e \$2,\$3,\$4'
.*:5: Error: unrecognized extended version of MIPS16 opcode `divu\.e \$3,\$4,\$5'
.*:6: Error: unrecognized extended version of MIPS16 opcode `ddiv\.e \$4,\$5,\$6'
.*:7: Error: unrecognized extended version of MIPS16 opcode `ddivu\.e \$5,\$6,\$7'
.*:8: Error: unrecognized extended version of MIPS16 opcode `rem\.e \$6,\$7,\$16'
.*:9: Error: unrecognized extended version of MIPS16 opcode `remu\.e \$6,\$7,\$17'
.*:10: Error: unrecognized extended version of MIPS16 opcode `drem\.e \$2,\$3,\$4'
.*:11: Error: unrecognized extended version of MIPS16 opcode `dremu\.e \$3,\$4,\$5'
.*:12: Error: unrecognized extended version of MIPS16 opcode `mul\.e \$4,\$5,\$6'
.*:13: Error: unrecognized extended version of MIPS16 opcode `dmul\.e \$5,\$6,\$7'
.*:14: Error: unrecognized extended version of MIPS16 opcode `subu\.e \$2,-32767'
.*:15: Error: unrecognized extended version of MIPS16 opcode `subu\.e \$3,16'
.*:16: Error: unrecognized extended version of MIPS16 opcode `subu\.e \$4,32768'
.*:17: Error: unrecognized extended version of MIPS16 opcode `subu\.e \$3,\$7,-16383'
.*:18: Error: unrecognized extended version of MIPS16 opcode `subu\.e \$4,\$16,4'
.*:19: Error: unrecognized extended version of MIPS16 opcode `subu\.e \$5,\$17,16384'
.*:20: Error: unrecognized extended version of MIPS16 opcode `dsubu\.e \$4,-32767'
.*:21: Error: unrecognized extended version of MIPS16 opcode `dsubu\.e \$6,6'
.*:22: Error: unrecognized extended version of MIPS16 opcode `dsubu\.e \$7,32768'
.*:23: Error: unrecognized extended version of MIPS16 opcode `dsubu\.e \$2,\$4,-16383'
.*:24: Error: unrecognized extended version of MIPS16 opcode `dsubu\.e \$3,\$7,8'
.*:25: Error: unrecognized extended version of MIPS16 opcode `dsubu\.e \$4,\$5,16384'
.*:26: Error: unrecognized extended version of MIPS16 opcode `beq\.e \$2,\$3,1b'
.*:27: Error: unrecognized extended version of MIPS16 opcode `bne\.e \$4,\$5,1b'
.*:28: Error: unrecognized extended version of MIPS16 opcode `blt\.e \$6,\$7,1b'
.*:29: Error: unrecognized extended version of MIPS16 opcode `bltu\.e \$16,\$17,1b'
.*:30: Error: unrecognized extended version of MIPS16 opcode `ble\.e \$4,\$7,1b'
.*:31: Error: unrecognized extended version of MIPS16 opcode `bleu\.e \$5,\$6,1b'
.*:32: Error: unrecognized extended version of MIPS16 opcode `bge\.e \$4,\$16,1b'
.*:33: Error: unrecognized extended version of MIPS16 opcode `bgeu\.e \$5,\$17,1b'
.*:34: Error: unrecognized extended version of MIPS16 opcode `bgt\.e \$4,\$6,1b'
.*:35: Error: unrecognized extended version of MIPS16 opcode `bgtu\.e \$5,\$7,1b'
.*:36: Error: unrecognized extended version of MIPS16 opcode `beq\.e \$2,1,1b'
.*:37: Error: unrecognized extended version of MIPS16 opcode `beq\.e \$3,65535,1b'
.*:38: Error: unrecognized extended version of MIPS16 opcode `bne\.e \$4,1,1b'
.*:39: Error: unrecognized extended version of MIPS16 opcode `bne\.e \$5,65535,1b'
.*:40: Error: unrecognized extended version of MIPS16 opcode `blt\.e \$6,-32768,1b'
.*:41: Error: unrecognized extended version of MIPS16 opcode `blt\.e \$7,32767,1b'
.*:42: Error: unrecognized extended version of MIPS16 opcode `bltu\.e \$16,-32768,1b'
.*:43: Error: unrecognized extended version of MIPS16 opcode `bltu\.e \$17,32767,1b'
.*:44: Error: unrecognized extended version of MIPS16 opcode `ble\.e \$2,-32769,1b'
.*:45: Error: unrecognized extended version of MIPS16 opcode `ble\.e \$3,32766,1b'
.*:46: Error: unrecognized extended version of MIPS16 opcode `bleu\.e \$4,-32769,1b'
.*:47: Error: unrecognized extended version of MIPS16 opcode `bleu\.e \$5,32766,1b'
.*:48: Error: unrecognized extended version of MIPS16 opcode `bge\.e \$6,-32768,1b'
.*:49: Error: unrecognized extended version of MIPS16 opcode `bge\.e \$7,32766,1b'
.*:50: Error: unrecognized extended version of MIPS16 opcode `bgeu\.e \$16,-32768,1b'
.*:51: Error: unrecognized extended version of MIPS16 opcode `bgeu\.e \$17,32767,1b'
.*:52: Error: unrecognized extended version of MIPS16 opcode `bgt\.e \$2,-32769,1b'
.*:53: Error: unrecognized extended version of MIPS16 opcode `bgt\.e \$3,32766,1b'
.*:54: Error: unrecognized extended version of MIPS16 opcode `bgtu\.e \$4,-32769,1b'
.*:55: Error: unrecognized extended version of MIPS16 opcode `bgtu\.e \$5,32766,1b'
.*:56: Error: unrecognized extended version of MIPS16 opcode `abs\.e \$2'
.*:57: Error: unrecognized extended version of MIPS16 opcode `abs\.e \$3,\$3'
.*:58: Error: unrecognized extended version of MIPS16 opcode `abs\.e \$4,\$5'
