target:
	vqwdotau.vv v16, v8, v31
	vqwdotas.vv v16, v8, v31
	vfwdota.vv v16, v8, v31
	vfqwdota.vv v16, v8, v31
	vfqwdota.alt.vv v16, v8, v31
	vqwdotau.vv v16, v8, v31, v0.t
	vqwdotas.vv v16, v8, v31, v0.t
	vfwdota.vv v16, v8, v31, v0.t
	vfqwdota.vv v16, v0, v31, v0.t
	vfqwdota.alt.vv v16, v0, v31, v0.t
