.*: Assembler messages:
.*: Error: illegal operands `fadd\.d .*'
.*: Error: illegal operands `fadd\.d .*'
.*: Error: illegal operands `fsub\.d .*'
.*: Error: illegal operands `fsub\.d .*'
.*: Error: illegal operands `fmul\.d .*'
.*: Error: illegal operands `fmul\.d .*'
.*: Error: illegal operands `fdiv\.d .*'
.*: Error: illegal operands `fdiv\.d .*'
.*: Error: illegal operands `fsqrt\.d .*'
.*: Error: illegal operands `fsqrt\.d .*'
.*: Error: illegal operands `fmin\.d .*'
.*: Error: illegal operands `fmax\.d .*'
.*: Error: illegal operands `fmadd\.d .*'
.*: Error: illegal operands `fmadd\.d .*'
.*: Error: illegal operands `fnmadd\.d .*'
.*: Error: illegal operands `fnmadd\.d .*'
.*: Error: illegal operands `fmsub\.d .*'
.*: Error: illegal operands `fmsub\.d .*'
.*: Error: illegal operands `fnmsub\.d .*'
.*: Error: illegal operands `fnmsub\.d .*'
.*: Error: illegal operands `fcvt\.w\.d .*'
.*: Error: illegal operands `fcvt\.w\.d .*'
.*: Error: illegal operands `fcvt\.wu\.d .*'
.*: Error: illegal operands `fcvt\.wu\.d .*'
.*: Error: unrecognized opcode `fcvt\.l\.d .*'
.*: Error: unrecognized opcode `fcvt\.l\.d .*'
.*: Error: unrecognized opcode `fcvt\.lu\.d .*'
.*: Error: unrecognized opcode `fcvt\.lu\.d .*'
.*: Error: unrecognized opcode `fcvt\.d\.l .*'
.*: Error: unrecognized opcode `fcvt\.d\.l .*'
.*: Error: unrecognized opcode `fcvt\.d\.lu .*'
.*: Error: unrecognized opcode `fcvt\.d\.lu .*'
.*: Error: illegal operands `fcvt\.s\.d .*'
.*: Error: illegal operands `fcvt\.s\.d .*'
.*: Error: illegal operands `fsgnj\.d .*'
.*: Error: illegal operands `fsgnjn\.d .*'
.*: Error: illegal operands `fsgnjx\.d .*'
.*: Error: illegal operands `feq\.d .*'
.*: Error: illegal operands `flt\.d .*'
.*: Error: illegal operands `fle\.d .*'
.*: Error: illegal operands `fgt\.d .*'
.*: Error: illegal operands `fge\.d .*'
.*: Error: illegal operands `fmv\.d .*'
.*: Error: illegal operands `fneg\.d .*'
.*: Error: illegal operands `fabs\.d .*'
.*: Error: illegal operands `fclass\.d .*'
