.*: Assembler messages:
.*: Error: vector register must be aligned to an EMUL=8 group
.*: Error: bad value for Zvbdota ci immediate field, value must be a multiple of 8 in 0..56
.*: Error: bad value for Zvbdota ci immediate field, value must be a multiple of 8 in 0..56
