[^:]*: Assembler messages:
.*: Warning: the TME feature has been deprecated -- `tstart x0'
.*: Warning: the TME feature has been deprecated -- `tstart X0'
.*: Warning: the TME feature has been deprecated -- `tstart x15'
.*: Warning: the TME feature has been deprecated -- `tstart X15'
.*: Warning: the TME feature has been deprecated -- `tstart x30'
.*: Warning: the TME feature has been deprecated -- `tstart X30'
.*: Warning: the TME feature has been deprecated -- `tcommit'
.*: Warning: the TME feature has been deprecated -- `tcommit'
.*: Warning: the TME feature has been deprecated -- `ttest x0'
.*: Warning: the TME feature has been deprecated -- `ttest X30'
.*: Warning: the TME feature has been deprecated -- `tcancel 0'
.*: Warning: the TME feature has been deprecated -- `tcancel 65535'
.*: Warning: the TME feature has been deprecated -- `tcancel 0xffff'
.*: Warning: the TME feature has been deprecated -- `tcancel 0XA'
